import React, { useState, useCallback, useEffect} from 'react';
import ReactDOM from 'react-dom';
import { csv, arc, pie, json } from 'd3';
import ReactDropdown from 'react-dropdown';
import { useUSMap } from './useUSMap';
import { Marks, Marks2 } from './Marks';

import { northEastStates } from './northEastStates';
import { midwestStates } from './midwestStates';
import { westStates } from './westStates';
import { southStates } from './southStates';

const csvUrl =
  'https://gist.githubusercontent.com/nasmith2/f7306cec68cf23c53a77f03efe7d70c0/raw/technologyChangeBetterOrWorse.csv';

const menuHeight = 40;
const width = 960;
const height = 500 - menuHeight;
const centerX = width / 2;
const centerY = height / 2;
const largeRadius = width / 6;
const smallRadius = width / 15;
const mapRadius = width / 25;


const pieArc = arc()
  .innerRadius(0)
  .outerRadius(largeRadius);

const pieArcSmall = arc()
  .innerRadius(0)
  .outerRadius(smallRadius);

const pieArcMap = arc()
  .innerRadius(0)
  .outerRadius(mapRadius);

const legendCircle = arc()
  .innerRadius(0)
  .outerRadius(width / 90);

const attributes = [
  { value: 'better', label: 'For the Better' },
  { value: 'worse', label: 'For the Worse' },
  { value: 'unknown', label: 'Do not know' },
  { value: 'refused', label: 'Refused to Answer' },
  { value: 'none', label: 'None' }
];

const viewAttributes = [
  { value: 'map', label: 'Map View' },
  { value: 'default', label: 'Default View' }
];

const chartAttributes = [
  { value: 'memoryImplant', label: 'Brain Implant to Improve Memory' },
  { value: 'driverlessCar', label: 'Would you get into a Driverless Car' },
  { value: 'technologyChange', label: 'How People Think Technology Change in the next 50 Years will affect lives' },
  { value: 'labMeat', label: 'Eat Meat Grown in a lab' },
  { value: 'alterDNA', label: "Parents Alterning Child's DNA" },
  { value: 'infoImplant', label: 'Implants to show Surrounding Information' },
  { value: 'robotsForDisabled', label: 'Lifelike Robots as Caregivers for Elderly/Disabled' },
  { value: 'flyingDrones', label: 'Drones Having Permission to Fly in US Airspace' }
  ];

const App = () => {
    const usMap = useUSMap();
  	const northEast = northEastStates();
  	const midwest = midwestStates();
    const south = southStates();
    const west = westStates();
    const [data, setData] = useState(null);
  
    const initialdropdownAttribute = 'none';
    const [dropdownAttribute, setDropdownAttribute] = useState(initialdropdownAttribute);
    const dropdownValue = d => d[dropdownAttribute];

    const initialViewDropdownAttribute = 'default';
    const [viewDropdownAttribute, setViewDropdownAttribute] = useState(initialViewDropdownAttribute);
    const viewDropdownValue = d => d[viewDropdownAttribute];
  
  	const initialChartDropdownAttribute = 'technologyChange';
    const [chartDropdownAttribute, setChartDropdownAttribute] = useState(initialChartDropdownAttribute);
    const chartDropdownValue = d => d[chartDropdownAttribute];
  
    useEffect(() => {
      csv(csvUrl).then(setData);
    }, []);

    if (!data) {
      return <pre>Loading...</pre>;
    }
  
    const chartPie = pie()
                        .value(1)
                        .sort(null);

    // Have a look at the attributes available in the console!
   console.dir(data);

  // declare the temp arrarys
  var driverlessCarArray = [];
  var alterDNAArray = [];
  var lifelikeRobotCaregiversArray = [];
  var dronesArrary = [];
  var implantArray = [];
  var techChangeOnLivesArray = [];
  var eatGrownMeatArray = [];
  var implantsForMemoryArray = [];
  var index = -1;
  var toContinue = false;  
  var selection = 0;
  var sortValue = 'none';

  // census temp arrays
  var northeastArray = [];
  var midwestArray = [];
  var southArray = [];
  var westArray = [];
  var northeastIndex = 0;
  var midwestIndex = 0;
  var southIndex = 0;
  var westIndex = 0;
  var graphShow = 'Tech change affect on lives';
  
  if(viewDropdownAttribute == 'default')
  {
    console.log('default view');
    
    //not the way I wanted to do this but I could not get it to work automatically
    for(let i = 0; i < data.length; ++i)
    {
      toContinue = false;  
      switch(dropdownAttribute)
      {
        case 'better':
          if(data[i]['Tech change affect on lives'] != 'Mostly better')
          {
            toContinue = true;
            selection = 1;
          }
          else
          {
            ++index; 
          }
          break;
        case 'worse':
          if(data[i]['Tech change affect on lives'] != 'Mostly worse')
          {
            toContinue = true;
            selection = 2;
          }
          else
          {
            ++index; 
          }
          break;
        case 'unknown':
          if(data[i]['Tech change affect on lives'] != "Don't Know")
          {
            toContinue = true;
            selection = 3;
          }
          else
          {
            ++index; 
          }
          break;
        case 'refused':
          if(data[i]['Tech change affect on lives'] != 'Refused')
          {
            toContinue = true;
            selection = 4;
          }
          else
          {
            ++index; 
          }
          break;
        case 'none':
        default:
          selection = 0;
          ++index;
          break;
      }

      switch(data[i]['Tech change affect on lives'])
      {
        case 'Mostly better':
          if((selection == 0) || (selection == 1))
          {
            techChangeOnLivesArray[i] = 'green'; //green
          }
          else
          {
            techChangeOnLivesArray[i] = 'hsla(128, 100%, 50%, .05)'; //light green
          }  
          break;
        case 'Mostly worse':
          if((selection == 0) || (selection == 2))
          {
            techChangeOnLivesArray[i] = 'red'; //red
          }
          else
          {
            techChangeOnLivesArray[i] = 'hsla(0, 100%, 50%, .05)'; // light red
          }
          break;
        case "Don't Know":
          if((selection == 0) || (selection == 3))
          {
            techChangeOnLivesArray[i] = 'blue'; // blue
          }
          else
          {
            techChangeOnLivesArray[i] = 'hsla(240, 100%, 50%, .05)'; // light blue
          }
          break;
          //default should just be Refused option, but if not
        default:
          if((selection == 0) || (selection == 4))
          {
            techChangeOnLivesArray[i] = 'black'; // black
          }
          else
          {
            techChangeOnLivesArray[i] = 'hsla(10, 10%, 50%, .05)'; // grey
          }
          break;
      }

      if(toContinue)
      {
        continue;
      }

      switch(data[i]['Brain implant to improve memory or mental capacity'])
      {
        case 'Yes, would do this':
          implantsForMemoryArray[index] = '#008000';
          break;
        case 'No, would not do this':
          implantsForMemoryArray[index] = '#ff0000';
          break;
        case "Don't know":
          implantsForMemoryArray[index] = '#0000ff';
          break;
          //default should just be Refused option, but if not
        default:
          implantsForMemoryArray[index] = '#0f0f0f'; // black
          break;
      }

      switch(data[i]['Eat meat grown in lab'])
      {
        case 'Yes, would do this':
          eatGrownMeatArray[index] = '#008000';
          break;
        case 'No, would not do this':
          eatGrownMeatArray[index] = '#ff0000';
          break;
        case "Don't know":
          eatGrownMeatArray[index] = '#0000ff';
          break;
          //default should just be Refused option, but if not
        default:
          eatGrownMeatArray[index] = '#0f0f0f'; // black
          break;
      }    

      switch(data[i]['Ride in a driverless car'])
      {
        case 'Yes, would do this':
          driverlessCarArray[index] = '#008000';
          break;
        case 'No, would not do this':
          driverlessCarArray[index] = '#ff0000';
          break;
        case "Don't know":
          driverlessCarArray[index] = '#0000ff';
          break;
          //default should just be Refused option, but if not
        default:
          driverlessCarArray[index] = '#0f0f0f'; // black
          break;
      }

      switch(data[i]['Parents can alter DNA of chidren'])
      {
        case 'Change for the better':
          alterDNAArray[index] = '#008000'; //green
          break;
        case 'Change for the worse':
          alterDNAArray[index] = '#ff0000'; //red
          break;
        case "Don't know":
          alterDNAArray[index] = '#0000ff'; // blue
          break;
        case "Both good and bad":
          alterDNAArray[index] = '#800080'; // purple
          break;
          //default should just be Refused option, but if not
        default:
          alterDNAArray[index] = '#0f0f0f'; // black
          break;
      }

      switch(data[i]['Lifelike robots become primary caregivers'])
      {
        case 'Change for the better':
          lifelikeRobotCaregiversArray[index] = '#008000'; //green
          break;
        case 'Change for the worse':
          lifelikeRobotCaregiversArray[index] = '#ff0000'; //red
          break;
        case "Don't know":
          lifelikeRobotCaregiversArray[index] = '#0000ff'; // blue
          break;
        case "Both good and bad":
          lifelikeRobotCaregiversArray[index] = '#800080'; // purple
          break;
          //default should just be Refused option, but if not
        default:
          lifelikeRobotCaregiversArray[index] = '#0f0f0f'; // black
          break;
      }

      switch(data[i]['personal and commercial drones are given permission to fly through U.S. airspace'])
      {
        case 'Change for the better':
          dronesArrary[index] = '#008000'; //green
          break;
        case 'Change for the worse':
          dronesArrary[index] = '#ff0000'; //red
          break;
        case "Don't know":
          dronesArrary[index] = '#0000ff'; // blue
          break;
        case "Both good and bad":
          dronesArrary[index] = '#800080'; // purple
          break;
          //default should just be Refused option, but if not
        default:
          dronesArrary[index] = '#0f0f0f'; // black
          break;
      }

      switch(data[i]['Most people wear implants or other devices to show them info on world around them'])
      {
        case 'Change for the better':
          implantArray[index] = '#008000'; //green
          break;
        case 'Change for the worse':
          implantArray[index] = '#ff0000'; //red
          break;
        case "Don't know":
          implantArray[index] = '#0000ff'; // blue
          break;
        case "Both good and bad":
          implantArray[index] = '#800080'; // purple
          break;
          //default should just be Refused option, but if not
        default:
          implantArray[index] = '#0f0f0f'; // black
          break;
      }
    }
  }
  else if(viewDropdownAttribute == 'map')
  {
    console.log('map selection');
    
    switch(chartDropdownAttribute)
    {
      case 'memoryImplant':
        graphShow = 'Brain implant to improve memory or mental capacity';
        break;
      case 'driverlessCar':
        graphShow = 'Ride in a driverless car';
        break;
      case 'labMeat':
        graphShow = 'Eat meat grown in lab';
        break;
      case 'alterDNA':
        graphShow = 'Parents can alter DNA of chidren';
        break;
      case 'infoImplant':
        graphShow = 'Most people wear implants or other devices to show them info on world around them';
        break;
      case 'robotsForDisabled':
        graphShow = 'Lifelike robots become primary caregivers';
        break;
      case 'flyingDrones':
        graphShow = 'personal and commercial drones are given permission to fly through U.S. airspace';
        break;
      case 'technologyChange':
      default:
        graphShow = 'Tech change affect on lives';
        break;
    } 
    for(let i = 0; i < data.length; ++i)
    {
      switch(data[i]['cregion'])
      {
        case 'South':
          switch(data[i][graphShow])
          {
            case 'Mostly better':
            case 'Yes, would do this':
            case 'Change for the better':
              southArray[southIndex] = '#008000'; //green
              break;
            case 'Mostly worse':
            case 'Change for the worse':
            case 'No, would not do this':
              southArray[southIndex] = '#ff0000'; //red
              break;
            case "Don't Know":
            case "Don't know":
              southArray[southIndex] = '#0000ff'; // blue
              break;
            case "Both good and bad":
              southArray[southIndex] = '#800080'; // purple
              console.dir(data[i][graphShow]);
              break;
              //default should just be Refused option, but if not
            default:
              southArray[southIndex] = '#0f0f0f'; // black
              break;
          }
          ++southIndex;
          break;
        case 'West':
          switch(data[i][graphShow])
          {
            case 'Mostly better':
            case 'Yes, would do this':
            case 'Change for the better':
              westArray[westIndex] = '#008000'; //green
              break;
            case 'Mostly worse':
            case 'Change for the worse':
            case 'No, would not do this':
              westArray[westIndex] = '#ff0000'; //red
              break;
            case "Don't Know":
            case "Don't know":
              westArray[westIndex] = '#0000ff'; // blue
              break;
            case "Both good and bad":
              westArray[westIndex] = '#800080'; // purple
              break;
              //default should just be Refused option, but if not
            default:
              westArray[westIndex] = '#0f0f0f'; // black
              break;
          }
          ++westIndex;
          break;
        case 'Midwest':
          switch(data[i][graphShow])
          {
            case 'Mostly better':
            case 'Yes, would do this':
            case 'Change for the better':
              midwestArray[midwestIndex] = '#008000'; //green
              break;
            case 'Mostly worse':
            case 'Change for the worse':
            case 'No, would not do this':
              midwestArray[midwestIndex] = '#ff0000'; //red
              break;
            case "Don't Know":
            case "Don't know":
              midwestArray[midwestIndex] = '#0000ff'; // blue
              break;
            case "Both good and bad":
              midwestArray[midwestIndex] = '#800080'; // purple
              break;
              //default should just be Refused option, but if not
            default:
              midwestArray[midwestIndex] = '#0f0f0f'; // black
              break;
          }
          ++midwestIndex;
          break;
        case 'NorthEast':
          switch(data[i][graphShow])
          {
            case 'Mostly better':
            case 'Yes, would do this':
            case 'Change for the better':
              northeastArray[northeastIndex] = '#008000'; //green
              break;
            case 'Mostly worse':
            case 'Change for the worse':
            case 'No, would not do this':
              northeastArray[northeastIndex] = '#ff0000'; //red
              break;
            case "Don't Know":
            case "Don't know":
              northeastArray[northeastIndex] = '#0000ff'; // blue
              break;
            case "Both good and bad":
              northeastArray[northeastIndex] = '#800080'; // purple
              break;
              //default should just be Refused option, but if not
            default:
              northeastArray[northeastIndex] = '#0f0f0f'; // black
              break;
          }
          ++northeastIndex;
          break;
        default:
          // shouldn't happen but just in case
          console.log("Error " + data[i]['cregion']);
      }
    }
  }
  else
  {
   	console.log("Error, nothign to implement"); 
  }
    
    driverlessCarArray.sort();
    alterDNAArray.sort();
    lifelikeRobotCaregiversArray.sort();
    dronesArrary.sort();
    implantArray.sort();
    techChangeOnLivesArray.sort();
    implantsForMemoryArray.sort();
    eatGrownMeatArray.sort();

  	southArray.sort();
  	westArray.sort();
  	midwestArray.sort();
  	northeastArray.sort();
  
    // Formula gotten from https://stackoverflow.com/questions/5737975/circle-drawing-with-svgs-arc-path/10477334#10477334
    function calculatePath(radius, cx, cy)
    {
      return "M " + cx + " " + cy + " m " + (-radius) + ", 0 a " + radius +"," + radius + " 0 1,1 "+(radius * 2)+",0 a "+radius+"," + radius +" 0 1,1 "+(-(radius * 2))+",0";
    }

    function interaction(e)
    {
      var color = e.target['attributes'][1]['nodeValue'];  
      //console.dir(e.target);
      console.dir(color);
      if(color == 'green')
      {
        if(sortValue != 'better')
        {
          setDropdownAttribute('better');
          sortValue = 'better';
        }
        else
        {
          setDropdownAttribute('none')
          sortValue = 'none';
        }
      }
      else if(color == 'red' )
      {
        if(sortValue != 'worse')
        {
          setDropdownAttribute('worse')
          sortValue = 'worse';
        }
        else
        {
          setDropdownAttribute('none')
          sortValue = 'none';
        }
      }
      else if(color == 'blue' )
      {
        if(sortValue != 'unknown')
        {
          setDropdownAttribute('unknown')
          sortValue = 'unknown';
        }
        else
        {
          setDropdownAttribute('none')
          sortValue = 'none';
        }
      }
      else if(color == 'black' )
      {
        if(sortValue != 'black')
        {
          setDropdownAttribute('refused')
          sortValue = 'refused';
        }
        else
        {
          setDropdownAttribute('none')
          sortValue = 'none';
        }
      }
      else
      {
        setDropdownAttribute('none')
        sortValue = 'none';
      }
    }
  
  if(viewDropdownAttribute == 'default')
  {
    return (
        <>
          <div className="menus-container">
            <span className="dropdown-label">Sort</span>
            <ReactDropdown
              options={attributes}
              value={dropdownAttribute}
              onChange={({ value }) => setDropdownAttribute(value)}
            />

            <span className="dropdown-label">Views</span>
            <ReactDropdown
              options={viewAttributes}
              value={viewDropdownAttribute}
              onChange={({ value }) => setViewDropdownAttribute(value)}
            />
          </div>


          <svg width={width} height={height}>

            // Center
            <g transform={`translate(${centerX},${centerY})`}>
              <path fill="transparent" id="techChangeTextCurve"d={calculatePath(largeRadius + 3, 0, 0)}/>
               <text>
                 <textPath alignment-baseline="top" xlink:href="#techChangeTextCurve">
                    How People think Technology Change in the next 50 years will affect lives
                  </textPath>
              </text>
              {  
                // So the designs that were being made was because it was trying to draw each individual pie
                // This means that if you make the stroke the same as the data then it elimates the design
                chartPie(techChangeOnLivesArray).map(d => (
                  <path d={pieArc(d)}  fill={d.data} stroke={d.data} onClick={interaction} />
                ))
              }   
            </g>

            // Legend
            <text x="40" y = "15" >Legend</text>
            <circle
              cx = { 25 }
              cy = { 30 }
              r = { 10 }
              fill = { '#008000' }
            />
            <text x="40" y = "35">Yes/For the Better</text>

            <circle
              cx = { 25 }
              cy = { 55 }
              r = { 10 }
              fill = { '#ff0000' }
            />
            <text x="40" y = "60">No/For the Worse</text>

            <circle
              cx = { 25 }
              cy = { 80 }
              r = { 10 }
              fill = { '#0000ff' }
            />
            <text x="40" y = "85">Don't Know</text>

            <circle
              cx = { 25 }
              cy = { 105 }
              r = { 10 }
              fill = { '#800080' }
            />
            <text x="40" y = "110">Both Better and Worse</text>

            <circle
              cx = { 25 }
              cy = { 130 }
              r = { 10 }
              fill = { '#0f0f0f' }
            />
            <text x="40" y = "135">Refused to answer</text>

            // Center Left
            <g transform={`translate(${centerX-350},${centerY})`}>
              <path fill="transparent" id="carChangeTextCurve"d={calculatePath(smallRadius + 3, 0, 0)}/>
               <text>
                 <textPath alignment-baseline="top" xlink:href="#carChangeTextCurve">
                    Would you get into Driverless car
                  </textPath>
              </text>
              {
                chartPie(driverlessCarArray).map(d => (
                <path fill={d.data} stroke={d.data} d={pieArcSmall(d)} />
                ))
              }
            </g>

            // Bottom Left-right
            <g transform={`translate(${centerX-200},${centerY + 150})`}>
              <path fill="transparent" id="dnaChangeTextCurve"d={calculatePath(smallRadius + 3, 0, 0)}/>
               <text>
                 <textPath alignment-baseline="top" xlink:href="#dnaChangeTextCurve">
                    Parents Alterning Child's DNA
                  </textPath>
              </text>
              {
                chartPie(alterDNAArray).map(d => (
                <path fill={d.data} stroke={d.data} d={pieArcSmall(d)} />
                ))
              }
            </g>

            // Bottom Left - left
            <g transform={`translate(${centerX-375},${centerY + 150})`}>
              <path fill="transparent" id="meatChangeTextCurve"d={calculatePath(smallRadius + 3, 0, 0)}/>
               <text>
                 <textPath alignment-baseline="top" xlink:href="#meatChangeTextCurve">
                    Eat Meat Grown in a Lab
                  </textPath>
              </text>
              {
                chartPie(eatGrownMeatArray).map(d => (
                <path fill={d.data} stroke={d.data} d={pieArcSmall(d)} />
                ))
              }
            </g>

            // Center Right
            <g transform={`translate(${centerX + 350},${centerY})`}>
              <path fill="transparent" id="caregiversChangeTextCurve"d={calculatePath(smallRadius + 3, 0, 0)}/>
               <text>
                 <textPath alignment-baseline="top" xlink:href="#caregiversChangeTextCurve">
                    Lifelike Robots as Caregivers for Elderly/Disabled
                  </textPath>
              </text>
              {
                chartPie(lifelikeRobotCaregiversArray).map(d => (
                <path fill={d.data} stroke={d.data} d={pieArcSmall(d)} />
                ))
              }
            </g>

            // bottom Right
            <g transform={`translate(${centerX + 250},${centerY+150})`}>
               <path fill="transparent" id="dronesChangeTextCurve"d={calculatePath(smallRadius + 3, 0, 0)}/>
               <text>
                 <textPath alignment-baseline="top" xlink:href="#dronesChangeTextCurve">
                    Drones Having Permission to Fly in Airspace
                  </textPath>
              </text>
              {
                chartPie(dronesArrary).map(d => (
                <path fill={d.data} stroke={d.data} d={pieArcSmall(d)} />
                ))
              }
            </g>

            // Top Right
            <g transform={`translate(${centerX + 250},${centerY-150})`} id="test">
            <path fill="transparent" id="implantsChangeTextCurve"d={calculatePath(smallRadius + 3, 0, 0)}/>
               <text>
                 <textPath alignment-baseline="top" xlink:href="#implantsChangeTextCurve">
                    Implants to Show Surrounding Information
                  </textPath>
              </text>
              {
                chartPie(implantArray).map(d => (
                <path fill={d.data} stroke={d.data} d={pieArcSmall(d)} />
                ))
              }
            </g>

            // Top Left
            <g transform={`translate(${centerX - 220},${centerY-150})`} id="test">
            <path fill="transparent" id="brainImplantsChangeTextCurve"d={calculatePath(smallRadius + 3, 0, 0)}/>
               <text>
                 <textPath alignment-baseline="top" xlink:href="#brainImplantsChangeTextCurve">
                    Brain implant to improve memory or mental capacity
                  </textPath>
              </text>
              {
                chartPie(implantsForMemoryArray).map(d => (
                <path fill={d.data} stroke={d.data} d={pieArcSmall(d)} />
                ))
              }
            </g>
          </svg>
        </>
    );
  }
  else if(viewDropdownAttribute == 'map')
  {
    return (
        <>
          <div className="menus-container">
            <span className="chartDropdown-label">Chart</span>
            <ReactDropdown
              options={chartAttributes}
              value={chartDropdownAttribute}
              onChange={({ value }) => setChartDropdownAttribute(value)}
            />
            <span className="viewsDropdown-label">Views</span>
            <ReactDropdown
              options={viewAttributes}
              value={viewDropdownAttribute}
              onChange={({ value }) => setViewDropdownAttribute(value)}
            />
          </div>

          <svg width={width} height={height}>
            <g>
              <Marks 
              usMap={usMap}
            	/>
            </g>
            <g className="marksNorth">
              <Marks2
              usMap={northEast}
            	/>
            </g>
						<g className="marksMidwest">
                <Marks2
                usMap={midwest}
                />
            </g>
            <g className="marksWest">
                <Marks2
                usMap={west}
                />
            </g>
            <g className="marksSouth">
                <Marks2
                usMap={south}
                />
            </g>
            
            // Northeast
            <g transform={`translate(${centerX + 250},${centerY - 130})`}>
              {
                chartPie(northeastArray).map(d => (
                <path fill={d.data} stroke={d.data} d={pieArcMap(d)} />
                ))
              }
            </g>
        	
            // Midwest
            <g transform={`translate(${centerX + 50},${centerY - 100})`}>
              {
                chartPie(midwestArray).map(d => (
                <path fill={d.data} stroke={d.data} d={pieArcMap(d)} />
                ))
              }
            </g>
            
            // South
            <g transform={`translate(${centerX + 150},${centerY + 75})`}>
              {
                chartPie(southArray).map(d => (
                <path fill={d.data} stroke={d.data} d={pieArcMap(d)} />
                ))
              }
            </g>
            
            // West
            <g transform={`translate(${centerX - 200},${centerY - 75})`}>
              {
                chartPie(westArray).map(d => (
                <path fill={d.data} stroke={d.data} d={pieArcMap(d)} />
                ))
              }
            </g>
        </svg>
      </>
      )
  }
  else // other
  {
    return (
        <>
          <div className="menus-container">
            <span className="dropdown-label">Sort</span>
            <ReactDropdown
              options={attributes}
              value={dropdownAttribute}
              onChange={({ value }) => setDropdownAttribute(value)}
            />

          </div>
        
          <svg width={width} height={height}>
            <text> Not Implemented Yet </text>
        	</svg>
      </>
      )
  }
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);